@@ -1,6 +1,6 @@
 SERVER = {
     'HOST': '66.6.152.52',
-    'PORT': 6697,
+    'PORT': 443,
     'SSL': True,
     'USERNAME': 'helgabot',
     'PASSWORD': 'b!gL4nd',
@@ -9,8 +9,7 @@ SERVER = {
 CHANNELS = [('#bottest',)]
 NICK = 'helgabot-dev'
 
-WEBHOOKS_CREDENTIALS = [
-]
+WEBHOOKS_CREDENTIALS = []
 
 NEWRELIC_WEBHOOK_ANNOUNCE_CHANNEL = '#bottest'
 NEWRELIC_API_KEY = '89c546ce2d34d281ed164f8c645d2a0d2c25be7dea1d00f'
